@@ -11,8 +11,8 @@ from .preprocess import reshape
 from .preprocess import normalize
 from .preprocess import _printTotal
 
-from .io import HDF5Dataset
-from .io import load_dataset
+# from .io import HDF5Dataset
+# from .io import load_dataset
 
 from .utils import readImg
 from .utils import saveNumpy
